@@ -1,5 +1,4 @@
 use crate::authentication::Authentication;
-#[cfg(test)]
 use crate::error::Error as ImageVaultError;
 use reqwest::{
     header::HeaderMap, header::HeaderValue, header::USER_AGENT, Client as ReqwestClient,
@@ -9,8 +8,6 @@ use std::str::FromStr;
 use std::sync::Arc;
 use url::Url;
 
-type BoxedError = Box<dyn std::error::Error>;
-
 const PACKAGE_VERSION: &'static str = env!("CARGO_PKG_VERSION");
 const PACKAGE_NAME: &'static str = "ImageVault-rs";
 
@@ -42,7 +39,7 @@ impl<T: Authentication + Sync> Client<T> {
         client_identity: &str,
         client_secret: &str,
         base_url: &str,
-    ) -> Result<Self, BoxedError> {
+    ) -> Result<Self, ImageVaultError> {
         let client = Client {
             client_identity: client_identity.to_string(),
             client_secret: client_secret.to_string(),
@@ -69,10 +66,10 @@ impl<T: Authentication + Sync> Client<T> {
     /// ```
     /// use imagevault::{
     ///     Client,
-    ///     authentication::ClientCredentialsAuthentication
+    ///     authentication::ClientCredentialsAuthentication,
     /// };
     ///
-    /// # fn test() -> Result<(), Box<dyn std::error::Error>> {
+    /// # fn test() -> Result<(), imagevault::error::Error> {
     /// let authentication = ClientCredentialsAuthentication::default();
     ///
     /// let client = Client::new(
@@ -90,7 +87,7 @@ impl<T: Authentication + Sync> Client<T> {
     }
 
     #[cfg(test)]
-    pub async fn test_authenticate(&self) -> Result<String, BoxedError> {
+    pub async fn test_authenticate(&self) -> Result<String, ImageVaultError> {
         let auth_unwrapped = self
             .authentication
             .as_ref()
@@ -128,17 +125,18 @@ mod tests {
     use std::sync::Arc;
     use crate::{authentication::DummyAuth, service::assets, testutil::get_test_data};
     use crate::Client;
+    use crate::error::Error as ImageVaultError;
     const INFO_ENDPOINT: &'static str = "/apiv2/assets/info";
     #[test]
     fn create_new_client() {
-        let client_ok: Result<Client<DummyAuth>, Box<dyn std::error::Error>> = Client::new(
+        let client_ok: Result<Client<DummyAuth>, ImageVaultError> = Client::new(
             "client_identifier",
             "client_secret",
             "https://imagevaultbaseurl.local",
         );
-        let client_bad_url: Result<Client<DummyAuth>, Box<dyn std::error::Error>> =
+        let client_bad_url: Result<Client<DummyAuth>, ImageVaultError> =
             Client::new("client_identifier", "client_secret", "asjdlkjasd");
-        let client_empty_url: Result<Client<DummyAuth>, Box<dyn std::error::Error>> =
+        let client_empty_url: Result<Client<DummyAuth>, ImageVaultError> =
             Client::new("client_identifier", "client_secret", "");
         assert!(client_ok.is_ok());
         assert!(client_bad_url.is_err());
