@@ -1,9 +1,8 @@
 use crate::authentication::Authentication;
 use crate::data::Category;
-use crate::error::Error;
+use crate::error::Error as ImageVaultError;
 use crate::Client;
 
-type BoxedError = Box<dyn std::error::Error>;
 const GET_CATEGORIES_ENDPOINT: &'static str = "/apiv2/categoryservice/getcategories";
 
 /// Calls `categoryservice/getcategories`.
@@ -23,7 +22,7 @@ const GET_CATEGORIES_ENDPOINT: &'static str = "/apiv2/categoryservice/getcategor
 ///     authentication::ClientCredentialsAuthentication
 /// };
 ///
-/// # async fn test() -> Result<(), Box<dyn std::error::Error>> {
+/// # async fn test() -> Result<(), imagevault::error::Error> {
 /// let authentication = ClientCredentialsAuthentication::default();
 /// let client = Client::new(
 ///     "identity",
@@ -38,11 +37,11 @@ const GET_CATEGORIES_ENDPOINT: &'static str = "/apiv2/categoryservice/getcategor
 /// ```
 pub async fn get_categories<T: Authentication + Sync>(
     client: &Client<T>,
-) -> Result<Vec<Category>, BoxedError> {
+) -> Result<Vec<Category>, ImageVaultError> {
     let auth_unwrapped = client
         .authentication
         .as_ref()
-        .ok_or_else(|| Error::AuthenticationMissing)?;
+        .ok_or_else(|| ImageVaultError::AuthenticationMissing)?;
     let auth_header = auth_unwrapped
         .lock()
         .await
@@ -61,7 +60,7 @@ pub async fn get_categories<T: Authentication + Sync>(
         .send()
         .await?;
     if let Err(err) = response.error_for_status_ref() {
-        return Err(Box::new(err));
+        return Err(err.into());
     } else {
         let result = response.json::<Vec<Category>>().await?;
         return Ok(result);
