@@ -1,10 +1,9 @@
 use crate::authentication::Authentication;
 use crate::data::MediaItem;
-use crate::error::Error;
+use crate::error::Error as ImageVaultError;
 use crate::Client;
 use serde::Serialize;
 
-type BoxedError = Box<dyn std::error::Error>;
 const SAVE_ENDPOINT: &'static str = "/apiv2/mediaservice/save";
 /// Calls `mediaservice/save`.
 ///
@@ -29,7 +28,7 @@ const SAVE_ENDPOINT: &'static str = "/apiv2/mediaservice/save";
 ///     authentication::ClientCredentialsAuthentication
 /// };
 ///
-/// # async fn test() -> Result<(), Box<dyn std::error::Error>> {
+/// # async fn test() -> Result<(), imagevault::error::Error> {
 /// let authentication = ClientCredentialsAuthentication::default();
 /// let client = Client::new(
 ///     "identity",
@@ -69,12 +68,12 @@ pub async fn save<T: Authentication + Sync>(
     client: &Client<T>,
     media_items: Vec<&MediaItem>,
     save_options: MediaServiceSaveOptions,
-) -> Result<(), BoxedError> {
+) -> Result<(), ImageVaultError> {
     let full_url = client.base_url.join(SAVE_ENDPOINT)?;
     let auth_unwrapped = client
         .authentication
         .as_ref()
-        .ok_or_else(|| Error::AuthenticationMissing)?;
+        .ok_or_else(|| ImageVaultError::AuthenticationMissing)?;
     let auth_header = auth_unwrapped
         .lock()
         .await
@@ -101,7 +100,7 @@ pub async fn save<T: Authentication + Sync>(
         .send()
         .await?;
     if let Err(err) = response.error_for_status_ref() {
-        return Err(Box::new(err));
+        return Err(err.into());
     } else {
         return Ok(());
     }
