@@ -1,5 +1,5 @@
 use crate::authentication::Authentication;
-use crate::error::Error;
+use crate::error::Error as ImageVaultError;
 use crate::Client;
 use bytesize::ByteSize;
 use reqwest::header::CONTENT_TYPE;
@@ -7,7 +7,6 @@ use std::fs::{metadata, File};
 use std::io::Read;
 use std::path::Path;
 
-type BoxedError = Box<dyn std::error::Error>;
 const UPLOAD_ENDPOINT: &'static str = "/apiv2/uploadservice/upload";
 const UPLOAD_CHUNK_SIZE: u64 = 50; // 50 kiB chunk size
 
@@ -29,10 +28,11 @@ const UPLOAD_CHUNK_SIZE: u64 = 50; // 50 kiB chunk size
 /// use imagevault::{
 ///     service::upload_service,
 ///     Client,
-///     authentication::ClientCredentialsAuthentication
+///     authentication::ClientCredentialsAuthentication,
+///     error::Error as ImageVaultError
 /// };
 ///
-/// # async fn test() -> Result<(), Box<dyn std::error::Error>> {
+/// # async fn test() -> Result<(), ImageVaultError> {
 /// let authentication = ClientCredentialsAuthentication::default();
 /// let client = Client::new(
 ///     "identity",
@@ -53,7 +53,7 @@ const UPLOAD_CHUNK_SIZE: u64 = 50; // 50 kiB chunk size
 pub async fn upload_from_path<T: Authentication + Sync>(
     client: &Client<T>,
     path: &Path,
-) -> Result<String, BoxedError> {
+) -> Result<String, ImageVaultError> {
     let _md = metadata(path)?;
     let file = File::open(path)?;
     upload_from_content(client, &file).await
@@ -79,7 +79,7 @@ pub async fn upload_from_path<T: Authentication + Sync>(
 ///     authentication::ClientCredentialsAuthentication
 /// };
 ///
-/// # async fn test() -> Result<(), Box<dyn std::error::Error>> {
+/// # async fn test() -> Result<(), imagevault::error::Error> {
 /// let authentication = ClientCredentialsAuthentication::default();
 /// let client = Client::new(
 ///     "identity",
@@ -101,7 +101,7 @@ pub async fn upload_from_path<T: Authentication + Sync>(
 pub async fn upload_from_content<T: Authentication + Sync, P: Read>(
     client: &Client<T>,
     mut content: P,
-) -> Result<String, BoxedError> {
+) -> Result<String, ImageVaultError> {
     let chunk_size = ByteSize::kib(UPLOAD_CHUNK_SIZE).as_u64();
     let mut file_id: Option<String> = None;
     loop {
@@ -129,7 +129,7 @@ pub async fn upload_from_content<T: Authentication + Sync, P: Read>(
         let auth_unwrapped = client
             .authentication
             .as_ref()
-            .ok_or_else(|| Error::AuthenticationMissing)?;
+            .ok_or_else(|| ImageVaultError::AuthenticationMissing)?;
         let auth_header = auth_unwrapped
             .lock()
             .await
@@ -150,7 +150,7 @@ pub async fn upload_from_content<T: Authentication + Sync, P: Read>(
             .send()
             .await?;
         if let Err(err) = response.error_for_status_ref() {
-            return Err(Box::new(err));
+            return Err(err.into());
         } else {
             file_id = Some(response.json::<String>().await?);
         }
