@@ -1,8 +1,7 @@
 use crate::authentication::Authentication;
-use crate::error::Error;
+use crate::error::Error as ImageVaultError;
 use crate::Client;
 
-type BoxedError = Box<dyn std::error::Error>;
 const DELETE_ENDPOINT: &'static str = "/apiv2/vaultservice/delete/";
 
 /// Calls `vaultservice/delete`.
@@ -24,7 +23,7 @@ const DELETE_ENDPOINT: &'static str = "/apiv2/vaultservice/delete/";
 ///     authentication::ClientCredentialsAuthentication
 /// };
 ///
-/// # async fn test() -> Result<(), Box<dyn std::error::Error>> {
+/// # async fn test() -> Result<(), imagevault::error::Error> {
 /// let authentication = ClientCredentialsAuthentication::default();
 /// let client = Client::new(
 ///     "identity",
@@ -41,11 +40,11 @@ const DELETE_ENDPOINT: &'static str = "/apiv2/vaultservice/delete/";
 pub async fn delete<T: Authentication + Sync>(
     client: &Client<T>,
     vault_id: i64,
-) -> Result<(), BoxedError> {
+) -> Result<(), ImageVaultError> {
     let auth_unwrapped = client
         .authentication
         .as_ref()
-        .ok_or_else(|| Error::AuthenticationMissing)?;
+        .ok_or_else(|| ImageVaultError::AuthenticationMissing)?;
     let auth_header = auth_unwrapped
         .lock()
         .await
@@ -67,7 +66,7 @@ pub async fn delete<T: Authentication + Sync>(
         .await?;
 
     if let Err(err) = response.error_for_status_ref() {
-        return Err(Box::new(err));
+        return Err(err.into());
     } else {
         return Ok(());
     }
